@@ -7,7 +7,7 @@ use Exporter;
 use Test::Builder;
 use base qw(Class::Accessor::Chained::Fast Exporter);
 __PACKAGE__->mk_accessors(qw(program));
-our $VERSION = "0.32";
+our $VERSION = "0.33";
 our @EXPORT  = qw(
     expect_run
     expect_handle
@@ -38,8 +38,9 @@ sub import {
 
 sub expect_run {
     my (%conf) = @_;
+    local $ENV{PERL_RL} = "Stub o=0";
     $expect = Expect::Simple->new(
-        {   Cmd           => "PERL_RL=\" o=0\" " . $conf{command},
+        {   Cmd           => $conf{command},
             Prompt        => $conf{prompt},
             DisconnectCmd => $conf{quit},
             Verbose       => 0,
@@ -107,7 +108,7 @@ Test::Expect - Automated driving and testing of terminal-based programs
   use Test::Expect;
   use Test::More tests => 13;
   expect_run(
-    command => "perl testme.pl",
+    command => ["perl", "testme.pl"],
     prompt  => 'testme: ',
     quit    => 'quit',
   );
@@ -135,11 +136,14 @@ the interactive program to run, what the prompt of the program is, and
 which command quits the program:
 
   expect_run(
-    command => "perl testme.pl",
+    command => ["perl", "testme.pl"],
     prompt  => 'testme: ',
     quit    => 'quit',
   );
 
+The C<command> may either be a string, or an arrayref of program and
+arguments; the latter for bypasses the shell.
+
 =head2 expect
 
 The expect subroutine is the catch all subroutine. You pass in the
@@ -189,11 +193,10 @@ Original module by Leon Brocard, E<lt>acme@astray.comE<gt>
 
 =head1 BUGS
 
-=for html
-<p>All bugs should be reported via email to
-L<bug-RT-Extension-SLA@rt.cpan.org|mailto:bug-RT-Extension-SLA@rt.cpan.org>
-or via the web at
-L<rt.cpan.org|http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-SLA>.</p>
+=for html <p>All bugs should be reported via email to <a
+href="mailto:bug-RT-Extension-SLA@rt.cpan.org">bug-RT-Extension-SLA@rt.cpan.org</a>
+or via the web at <a
+href="http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-SLA">rt.cpan.org</a>.</p>
 
 =for text
     All bugs should be reported via email to
